==> visual-third-party-1.0.6-ibk-sources.jar: com/tenqube/visual_third/manager/PrefManager.java <==


package com.tenqube.visual_third.manager;

import android.content.Context;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;


/**
 * Utilities and constants related to app preferences.
 */
public class PrefManager {

    private static final String TAG = PrefManager.class.getSimpleName();

    public static final String PREFIX = "TENQUBE_";

    public static final String ADMOB_BG_COLOR = PREFIX + "ADMOB_BG_COLOR";

    public static final String ADMOB_TITLE_COLOR = PREFIX + "ADMOB_TITLE_COLOR";

    public static final String ADMOB_CONTENT_COLOR = PREFIX + "ADMOB_CONTENT_COLOR";

    public static final String ADMOB_LABEL_COLOR = PREFIX + "ADMOB_LABEL_COLOR";

    public static final String ADMOB_LINK_COLOR = PREFIX + "ADMOB_LINK_COLOR";

    public static final String AD_VERSION = PREFIX + "AD_VERSION";

    public static final String NOTI_ICON_RES = PREFIX + "NOTI_ICON_RES";

    public static final String NOTI_CHANNEL = PREFIX + "NOTI_CHANNEL";

    public static final String NOTI_CHANNEL_NAME = PREFIX + "NOTI_CHANNEL_NAME";

    public static final String NOTI_CHANNEL_DESCRIPTION = PREFIX + "NOTI_CHANNEL_DESCRIPTION";

    public static final String NOTI_COLOR = PREFIX + "NOTI_COLOR";

    public static final String PARSING_RULE_VERSION = PREFIX + "PARSING_RULE_VERSION";

    public static final String NOTIFICATION_VERSION = PREFIX + "NOTIFICATION_VERSION";

    public static final String NOTIFICATION_DIVIDER = PREFIX + "NOTIFICATION_DIVIDER";

    public static final String UID = PREFIX + "UID";

    public static final String SEARCH_URL = PREFIX + "SEARCH_URL";

    public static final String SEARCH_API_KEY = PREFIX + "SEARCH_API_KEY";

    public static final String BULK_EXECUTED = PREFIX + "BULK_EXECUTED";

    public static final String SIGN_UP_TIME = PREFIX + "SIGN_UP_TIME";

    public static final String WEB_URL = PREFIX + "WEB_URL";

    public static final String QUALIFIER = PREFIX + "QUALIFIER";

    public static final String API_KEY = PREFIX + "API_KEY";

    public static final String CATEGORY_VERSION = PREFIX + "CATEGORY_VERSION";

    public static final String CLIP_CATEGORY_VERSION = PREFIX + "CLIP_CATEGORY_VERSION";

    public static final String ANALYSIS_VERSION = PREFIX + "ANALYSIS_VERSION";

    public static final String ACCESS_NOTI_LISTENER = PREFIX + "ACCESS_NOTI_LISTENER";

    public static final String TRAN_POPUP = PREFIX + "TRAN_POPUP";

    public static final String PARSING_RULE_KEY = PREFIX + "PARSING_RULE_KEY";

    public static final String SDK_ENABLED = PREFIX + "SDK_ENABLED";

    private static PrefManager mInstance;
    private Context context;
    public  static PrefManager getInstance(Context context){
        synchronized (PrefManager.class) {
            if(mInstance == null){
                mInstance = new PrefManager(context.getApplicationContext());
            }

        }
        return mInstance;
    }

    private PrefManager(Context context){
        this.context = context;
    }


    public boolean isEnabled(String key, boolean defaultValue){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        return sp.getBoolean(key, defaultValue);
    }

    public void saveBoolean(String key, boolean flag){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        sp.edit().putBoolean(key, flag).apply();
    }

    public int loadIntValue(String key, int defaultValue){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        return sp.getInt(key, defaultValue);
    }

    public void saveIntValue(String key, int value){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        sp.edit().putInt(key, value).apply();
    }


    public long loadLongValue(String key, long defaultValue){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        return sp.getLong(key, defaultValue);
    }

    public void saveLongValue(String key, long value){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        sp.edit().putLong(key, value).apply();
    }

    public String loadStringValue(String key, String defaultValue){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        return sp.getString(key, defaultValue);
    }

    public void saveStringValue(String key, String value){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        sp.edit().putString(key, value).apply();
    }

}

==> visual-third-party-1.2.1-ibk-sources.jar: com/tenqube/visual_third/manager/PrefManager.java <==


package com.tenqube.visual_third.manager;

import android.content.Context;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;


/**
 * Utilities and constants related to app preferences.
 */
public class PrefManager {

    private static final String TAG = PrefManager.class.getSimpleName();

    public static final String PREFIX = "TENQUBE_";

    public static final String DEEP_LINK = PREFIX + "DEEP_LINK";

    public static final String ADMOB_BG_COLOR = PREFIX + "ADMOB_BG_COLOR";

    public static final String ADMOB_TITLE_COLOR = PREFIX + "ADMOB_TITLE_COLOR";

    public static final String ADMOB_CONTENT_COLOR = PREFIX + "ADMOB_CONTENT_COLOR";

    public static final String ADMOB_LABEL_COLOR = PREFIX + "ADMOB_LABEL_COLOR";

    public static final String ADMOB_LINK_COLOR = PREFIX + "ADMOB_LINK_COLOR";

    public static final String AD_VERSION = PREFIX + "AD_VERSION";

    public static final String NOTI_ICON_RES = PREFIX + "NOTI_ICON_RES";

    public static final String NOTI_CHANNEL = PREFIX + "NOTI_CHANNEL";

    public static final String NOTI_CHANNEL_NAME = PREFIX + "NOTI_CHANNEL_NAME";

    public static final String NOTI_CHANNEL_DESCRIPTION = PREFIX + "NOTI_CHANNEL_DESCRIPTION";

    public static final String NOTI_COLOR = PREFIX + "NOTI_COLOR";

    public static final String PARSING_RULE_VERSION = PREFIX + "PARSING_RULE_VERSION";

    public static final String NOTIFICATION_VERSION = PREFIX + "NOTIFICATION_VERSION";

    public static final String NOTIFICATION_DIVIDER = PREFIX + "NOTIFICATION_DIVIDER";

    public static final String UID = PREFIX + "UID";

    public static final String SEARCH_URL = PREFIX + "SEARCH_URL";

    public static final String SEARCH_API_KEY = PREFIX + "SEARCH_API_KEY";

    public static final String BULK_EXECUTED = PREFIX + "BULK_EXECUTED";

    public static final String SIGN_UP_TIME = PREFIX + "SIGN_UP_TIME";

    public static final String WEB_URL = PREFIX + "WEB_URL";

    public static final String QUALIFIER = PREFIX + "QUALIFIER";

    public static final String APPLICATION_ID = PREFIX + "APPLICATION_ID";

    public static final String API_KEY = PREFIX + "API_KEY";

    public static final String CATEGORY_VERSION = PREFIX + "CATEGORY_VERSION";

    public static final String CLIP_CATEGORY_VERSION = PREFIX + "CLIP_CATEGORY_VERSION";

    public static final String ANALYSIS_VERSION = PREFIX + "ANALYSIS_VERSION";

    public static final String ACCESS_NOTI_LISTENER = PREFIX + "ACCESS_NOTI_LISTENER";

    public static final String TRAN_POPUP = PREFIX + "TRAN_POPUP";

    public static final String PARSING_RULE_KEY = PREFIX + "PARSING_RULE_KEY";

    public static final String SDK_ENABLED = PREFIX + "SDK_ENABLED";

    private static PrefManager mInstance;
    private Context context;
    public  static PrefManager getInstance(Context context){
        synchronized (PrefManager.class) {
            if(mInstance == null){
                mInstance = new PrefManager(context.getApplicationContext());
            }

        }
        return mInstance;
    }

    private PrefManager(Context context){
        this.context = context;
    }


    public boolean isEnabled(String key, boolean defaultValue){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        return sp.getBoolean(key, defaultValue);
    }

    public void saveBoolean(String key, boolean flag){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        sp.edit().putBoolean(key, flag).apply();
    }

    public int loadIntValue(String key, int defaultValue){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        return sp.getInt(key, defaultValue);
    }

    public void saveIntValue(String key, int value){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        sp.edit().putInt(key, value).apply();
    }


    public long loadLongValue(String key, long defaultValue){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        return sp.getLong(key, defaultValue);
    }

    public void saveLongValue(String key, long value){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        sp.edit().putLong(key, value).apply();
    }

    public String loadStringValue(String key, String defaultValue){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        return sp.getString(key, defaultValue);
    }

    public void saveStringValue(String key, String value){
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(context);
        sp.edit().putString(key, value).apply();
    }

}
